import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:wowit/common.dart';
import 'package:wowit/methods.dart';
import 'package:wowit/sql_service.dart';

class LoadingScreen extends StatelessWidget {
  const LoadingScreen({super.key});
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Center(
        child: Image.asset(
          'assets/images/loading_screen.png',
          height: 200,
        ),
      ),
    );
  }
}

class NoInternetScreen extends StatelessWidget {
  const NoInternetScreen({super.key});

  @override
  Widget build(BuildContext context) {
    return Center(
      child: Image.asset(
        'assets/images/404-error.png',
        height: 100,
        width: 100,
      ),
    );
  }
}

class MessageListScreen extends StatelessWidget {
  const MessageListScreen({
    super.key,
    this.data = const {},
    required this.currentRoute,
  });

  final Map<String, Object> data;
  final String currentRoute;

  @override
  Widget build(BuildContext context) {
    Object message =
        Methods.getDataHashMap(Common.messageIdBackUp, currentRoute) ?? {};
    if (message is Map<String, String>) {
      return Scaffold(
        appBar: AppBar(
          backgroundColor: Colors.white,
          title: const Text(
            'Danh sách message',
            style: TextStyle(
              color: Color(0xff2a367e),
              fontSize: 20,
            ),
          ),
          leading: IconButton(
            icon: const Icon(
              Icons.arrow_back_ios_rounded,
              color: Color(0xff2a367e),
              size: 24.0,
            ),
            onPressed: () {
              Get.back();
            },
          ),
        ),
        body: ListView.separated(
          padding: const EdgeInsets.all(16),
          separatorBuilder: (_, __) => const Divider(),
          itemCount: message.length,
          itemBuilder: (_, index) {
            String key = message.keys.elementAt(index);
            return Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                const SizedBox(height: 8),
                Text(key),
                const SizedBox(height: 8),
                wMessage(key, message[key] as String),
                const SizedBox(height: 8),
              ],
            );
          },
        ),
      );
    }
    return const Scaffold();
  }

  Widget wMessage(String key, String messageValue) {
    String text = messageValue;
    return Row(
      children: [
        Expanded(
          child: TextField(
            maxLines: null,
            controller: TextEditingController(text: text),
            onChanged: (value) => text = value,
          ),
        ),
        const SizedBox(
          width: 8,
        ),
        IconButton(
          onPressed: () {
            updateMessage(key, text);
          },
          icon: const Icon(
            Icons.send_outlined,
            size: 20,
          ),
        )
      ],
    );
  }

  void updateMessage(String key, String value) async {
    await SQLService.execute('sp_editMessage',
        params: {'messageId': key, 'title': value}).then((data) {
      var tmpList = Methods.getList(data, 'thongBao');
      if (tmpList.isNotEmpty &&
          Methods.getString(tmpList.first, 'message') == 'thanhCong') {
        Get.dialog(Dialog(
          backgroundColor: Colors.white,
          shape: RoundedRectangleBorder(
            borderRadius: BorderRadius.circular(10),
          ),
          child: Padding(
            padding:
                const EdgeInsets.only(top: 20, right: 20, left: 20, bottom: 8),
            child: Column(
                mainAxisAlignment: MainAxisAlignment.center,
                crossAxisAlignment: CrossAxisAlignment.center,
                mainAxisSize: MainAxisSize.min,
                children: [
                  const Text(
                    'Cập nhật thành công',
                    style: TextStyle(fontWeight: FontWeight.w600, fontSize: 14),
                  ),
                  const SizedBox(
                    height: 8,
                  ),
                  InkWell(
                    onTap: () {
                      Get.back();
                    },
                    child: Container(
                      padding: const EdgeInsets.all(8),
                      alignment: Alignment.center,
                      child: const Text(
                        'OK',
                        style: TextStyle(color: Color(0xff2a367e)),
                      ),
                    ),
                  )
                ]),
          ),
        ));
      }
    });
  }
}
